@@ -20,9 +20,11 @@ import octobot_tentacles_manager.configuration as tm_configuration
 
 import async_channel.constants as channel_constants
 import async_channel.enums as channel_enums
+import async_channel.channels as channels
 
 import octobot_commons.constants as common_constants
 import octobot_commons.errors as commons_errors
+import octobot_commons.enums as commons_enums
 import octobot_commons.tentacles_management as tentacles_management
 
 import octobot_evaluators.evaluators.channel as evaluator_channels
@@ -35,12 +37,16 @@ import octobot_evaluators.util as util
 
 class AbstractEvaluator(tentacles_management.AbstractTentacle):
     __metaclass__ = tentacles_management.AbstractTentacle
+    USER_INPUT_TENTACLE_TYPE = commons_enums.UserInputTentacleTypes.EVALUATOR
 
     def __init__(self, tentacles_setup_config: tm_configuration.TentaclesSetupConfiguration):
         super().__init__()
         # Evaluator matrix id
         self.matrix_id: str = None
 
+        # OctoBot id this evaluator has been started with
+        self.bot_id: str = None
+
         # Tentacle global setup configuration
         self.tentacles_setup_config: tm_configuration.TentaclesSetupConfiguration = tentacles_setup_config
 
@@ -80,9 +86,6 @@ class AbstractEvaluator(tentacles_management.AbstractTentacle):
         # Active tells if this evaluator is currently activated (an evaluator can be paused)
         self.is_active: bool = True
 
-        # Evaluators Channel consumer instance
-        self.evaluators_consumer_instance = None
-
         self.eval_note_time_to_live = None
         self.eval_note_changed_time = None
 
@@ -178,6 +181,9 @@ class AbstractEvaluator(tentacles_management.AbstractTentacle):
     def use_cache(cls):
         return False
 
+    def get_local_config(self):
+        return self.specific_config
+
     def _get_tentacle_registration_topic(self, all_symbols_by_crypto_currencies, time_frames, real_time_time_frames):
         currencies = [self.cryptocurrency]
         symbols = [self.symbol]
@@ -197,7 +203,8 @@ class AbstractEvaluator(tentacles_management.AbstractTentacle):
                                      if tf in trigger_timeframes]
         return currencies, symbols, available_time_frames
 
-    def initialize(self, all_symbols_by_crypto_currencies, time_frames, real_time_time_frames):
+    async def initialize(self, all_symbols_by_crypto_currencies, time_frames, real_time_time_frames, bot_id):
+        await self.reload_config(bot_id)
         currencies, symbols, time_frames = self._get_tentacle_registration_topic(all_symbols_by_crypto_currencies,
                                                                                  time_frames,
                                                                                  real_time_time_frames)
@@ -286,15 +293,36 @@ class AbstractEvaluator(tentacles_management.AbstractTentacle):
         """
         :return: success of the evaluator's start
         """
-        self.evaluators_consumer_instance = await evaluator_channels.get_chan(constants.EVALUATORS_CHANNEL,
-                                                                              self.matrix_id) \
-            .new_consumer(
+        self.bot_id = bot_id
+        self.consumers.append(
+            await evaluator_channels.get_chan(constants.EVALUATORS_CHANNEL, self.matrix_id).new_consumer(
                 self.evaluators_callback,
                 cryptocurrency=self.cryptocurrency if self.cryptocurrency else channel_constants.CHANNEL_WILDCARD,
                 symbol=self.symbol if self.symbol else channel_constants.CHANNEL_WILDCARD,
                 time_frame=self.time_frame if self.time_frame else channel_constants.CHANNEL_WILDCARD,
                 priority_level=self.priority_level,
             )
+        )
+
+        try:
+            import octobot_services.channel as services_channels
+            self.consumers.append(
+                await channels.get_chan(services_channels.UserCommandsChannel.get_name()).new_consumer(
+                    self.user_commands_callback,
+                    {"bot_id": bot_id, "subject": self.get_name()}
+                )
+            )
+        except KeyError:
+            # UserCommandsChannel might not be available
+            pass
+        except ImportError:
+            self.logger.warning("Can't connect to services channels")
+
+    async def user_commands_callback(self, bot_id, subject, action, data) -> None:
+        self.logger.debug(f"Received {action} command")
+        if action == commons_enums.UserCommands.RELOAD_CONFIG.value:
+            await self.reload_config(bot_id)
+            self.logger.debug("Reloaded configuration")
 
     async def stop(self) -> None:
         """
@@ -321,6 +349,27 @@ class AbstractEvaluator(tentacles_management.AbstractTentacle):
         else:
             self.logger.debug("Evaluator not started")
 
+    async def reload_config(self, bot_id: str) -> None:
+        self.set_default_config()
+        specific_config = api.get_tentacle_config(self.tentacles_setup_config, self.__class__)
+
+        if not specific_config and self.ALLOW_SUPER_CLASS_CONFIG:
+            # if nothing in config, try with any super-class' config file
+            for super_class in self.get_parent_evaluator_classes(AbstractEvaluator):
+                try:
+                    if specific_config := api.get_tentacle_config(self.tentacles_setup_config, super_class):
+                        break
+                except KeyError:
+                    pass  # super_class tentacle config not found
+        self.specific_config.update(specific_config)
+        await self.load_and_save_user_inputs(bot_id)
+
+    @classmethod
+    def create_local_instance(cls, _, tentacles_setup_config, tentacle_config):
+        return evaluator_factory.create_temporary_evaluator_with_local_config(
+            cls, tentacles_setup_config, tentacle_config, False
+        )
+
     def set_default_config(self):
         """
         To implement in subclasses if config necessary
